@@ -1,9 +1,9 @@
 package Sah::Schema::unix::groupname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-20'; # DATE
+our $DATE = '2021-07-22'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 our $schema = [str => {
     summary => 'Unix group name',
@@ -30,7 +30,7 @@ _
         {value=>'andy2', valid=>1},
         {value=>'an dy', valid=>0},
         {value=>'an.dy', valid=>1},
-        {value=>'a' x 33, value=>0, summary=>'Too long'},
+        {value=>'a' x 33, valid=>0, summary=>'Too long'},
     ],
 
 }];
@@ -50,7 +50,7 @@ Sah::Schema::unix::groupname - Unix group name
 
 =head1 VERSION
 
-This document describes version 0.016 of Sah::Schema::unix::groupname (from Perl distribution Sah-Schemas-Unix), released on 2021-07-20.
+This document describes version 0.017 of Sah::Schema::unix::groupname (from Perl distribution Sah-Schemas-Unix), released on 2021-07-22.
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,7 @@ Sample data:
 
  "an.dy"  # valid
 
- 0  # INVALID (Too long)
+ "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"  # INVALID (Too long)
 
 =head1 DESCRIPTION
 
